referrerpolicy=no-referrer-when-downgrade

place_order_allow_death

Function place_order_allow_death 

pub fn place_order_allow_death<T: Config>(max_amount: BalanceOf<T>, para_id: Id)
Create a single on demand core order. Will use the spot price for the current block and will reap the account if needed.

Parameters:

  • origin: The sender of the call, funds will be withdrawn from this account.
  • max_amount: The maximum balance to withdraw from the origin to place an order.
  • para_id: A ParaId the origin wants to provide blockspace for.

Errors:

  • InsufficientBalance: from the Currency implementation
  • QueueFull
  • SpotPriceHigherThanMaxAmount

Events:

  • OnDemandOrderPlaced

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::place_order_allow_death.